@@ -21,6 +21,7 @@ class EWAHSQLBaseOperator(EWAHBaseOperator):
     _ACCEPTED_EXTRACT_STRATEGIES = {
         EC.ES_FULL_REFRESH: True,
         EC.ES_INCREMENTAL: True,
+        EC.ES_SUBSEQUENT: True,
     }
 
     def __init__(
@@ -35,10 +36,19 @@ class EWAHSQLBaseOperator(EWAHBaseOperator):
         where_clauses: Optional[Union[str, List[str]]] = None,
         extra_params: Optional[dict] = None,
         batch_size: int = 100000,
+        use_limits_for_batches: bool = False,
         *args,
         **kwargs
     ):
         source_table_name = source_table_name or kwargs["target_table_name"]
+
+        # default subsequent_field to timestamp_column or primary_key_column_name
+        if kwargs.get("extract_strategy") == EC.ES_SUBSEQUENT:
+            kwargs["subsequent_field"] = kwargs.get(
+                "subsequent_field",
+                timestamp_column or kwargs.get("primary_key_column_name", None),
+            )
+
         super().__init__(*args, **kwargs)
 
         if isinstance(where_clauses, str):
@@ -71,6 +81,7 @@ class EWAHSQLBaseOperator(EWAHBaseOperator):
         self.timestamp_column = timestamp_column
         self.where_clauses = where_clauses
         self.batch_size = batch_size
+        self.use_limits_for_batches = use_limits_for_batches
 
     def ewah_execute(self, context):
         # called, potentially with a data_from and data_until
@@ -91,6 +102,15 @@ class EWAHSQLBaseOperator(EWAHBaseOperator):
                 )
             )
             params["data_until"] = self.data_until
+        if self.subsequent_field and self.test_if_target_table_exists():
+            where_clauses.append(
+                "{0} > {1}".format(
+                    self.subsequent_field, self._SQL_PARAMS.format("previous_max_value")
+                )
+            )
+            params["previous_max_value"] = self.get_max_value_of_column(
+                self.subsequent_field
+            )
 
         where_clauses = where_clauses or ["1 = 1"]
         sql = self.sql.format("\n  AND ".join(where_clauses))
@@ -99,5 +119,7 @@ class EWAHSQLBaseOperator(EWAHBaseOperator):
             params=params or None,  # Don't supply empty dict as params!
             return_dict=True,
             batch_size=self.batch_size,
+            use_limits=self.use_limits_for_batches,
+            order_by_columns=self.update_on_columns,
         ):
             self.upload_data(batch)
