@@ -8,10 +8,10 @@ from ewah.constants import EWAHConstants as EC
 
 import os
 import csv
+import pickle
 
 import snowflake.connector
-from tempfile import NamedTemporaryFile
-from airflow.utils.file import TemporaryDirectory
+from tempfile import NamedTemporaryFile, TemporaryDirectory
 from airflow.models import BaseOperator
 
 
@@ -35,6 +35,7 @@ class SnowflakeOperator(BaseOperator):
             database=self.database,
         )
         hook.execute(self.sql, commit=True, params=self._params)
+        hook.commit()
         hook.close()
 
 
@@ -71,15 +72,63 @@ class EWAHSnowflakeUploader(EWAHBaseUploader):
         super().__init__(EC.DWH_ENGINE_SNOWFLAKE, *args, **kwargs)
 
     def commit(self):
+        # Execute delayed upload
+        if hasattr(self, "_tempdir"):
+            # Upload data from pickled files in the correct order
+            for filename in [
+                str(i + 1)
+                for i in range(max([int(x) for x in os.listdir(self.tempdir)]))
+            ]:
+                self.log.info("Unpickling and uploading data from {0}".format(filename))
+                with open(self.tempdir + os.sep + filename, "rb") as pickle_file:
+                    kwargs = pickle.load(pickle_file)
+                    if (kwargs["upload_call_count"] > 1) or (
+                        not (kwargs["load_strategy"] == EC.LS_INSERT_REPLACE)
+                    ):
+                        super().detect_and_apply_schema_changes(
+                            new_schema_name=(
+                                kwargs["schema_name"] + kwargs["schema_suffix"]
+                            ),
+                            new_table_name=kwargs["table_name"],
+                            new_columns_dictionary=kwargs["columns_definition"],
+                            database=kwargs.get("database_name", None),
+                            drop_missing_columns=False,
+                            commit=False,
+                        )
+                    self._create_or_update_table_from_pickle(**kwargs)
+
+            self._tempdir.cleanup()
+            del self._tempdir
         self.dwh_hook.commit()
 
     def rollback(self):
-        self.dwh_hook.commit()
+        self.dwh_hook.rollback()
 
     def close(self):
         self.dwh_hook.close()
 
-    def _create_or_update_table(
+    @property
+    def tempdir(self):
+        if not hasattr(self, "_tempdir"):
+            self._tempdir = TemporaryDirectory(prefix="uploadtosnowflake")
+        return self._tempdir.name
+
+    def detect_and_apply_schema_changes(self, *args, **kwargs):
+        # Overwrite parent's function: delay execution until the commit command!
+        return (["(Execution delayed)"], ["(Execution delayed)"])
+
+    def _create_or_update_table(self, **kwargs):
+        """Instead of loading the data straight away, store the data as pickle and
+        load it into the DWH when
+        """
+        upload_call_count = kwargs["upload_call_count"]
+        self.log.info(
+            "Pickling data as {0} to load at the end...".format(str(upload_call_count))
+        )
+        with open(self.tempdir + os.sep + str(upload_call_count), "wb") as f:
+            pickle.dump(kwargs, f)
+
+    def _create_or_update_table_from_pickle(
         self,
         data,
         table_name,
@@ -88,7 +137,8 @@ class EWAHSnowflakeUploader(EWAHBaseUploader):
         columns_definition,
         columns_partial_query,
         update_on_columns,
-        drop_and_replace,
+        load_strategy,
+        upload_call_count,
         database_name=None,
         pk_columns=None,
     ):
@@ -154,15 +204,15 @@ class EWAHSnowflakeUploader(EWAHBaseUploader):
                     USE DATABASE "{2}";
                     USE SCHEMA "{3}";
                     DROP FILE FORMAT IF EXISTS {1}_format;
-                    CREATE OR REPLACE FILE FORMAT {1}_format
+                    CREATE FILE FORMAT {1}_format
                         type = 'CSV'
                         field_delimiter = ','
                         field_optionally_enclosed_by = '"'
                     ;
                     DROP STAGE IF EXISTS {1}_stage;
-                    CREATE OR REPLACE STAGE {1}_stage
+                    CREATE STAGE {1}_stage
                         file_format = {1}_format;
-                    PUT file://{0} @{1}_stage;
+                    PUT file://{0} @{1}_stage AUTO_COMPRESS = TRUE OVERWRITE = TRUE;
                     COPY INTO "{2}"."{3}"."{1}" FROM '@{1}_stage/{4}.gz';
                 """.format(
                     file_name,
@@ -174,7 +224,7 @@ class EWAHSnowflakeUploader(EWAHBaseUploader):
                 self.log.info("Uploading data to Snowflake...")
                 self.dwh_hook.execute(sql_upload)
 
-        if drop_and_replace or (
+        if (load_strategy == EC.LS_INSERT_REPLACE and upload_call_count == 1) or (
             not self.test_if_table_exists(
                 table_name=table_name,
                 schema_name=schema_name,
@@ -213,9 +263,10 @@ class EWAHSnowflakeUploader(EWAHBaseUploader):
                     USING "{0}"."{1}"."{3}" AS b
                     ON {4}
                     WHEN MATCHED THEN UPDATE
-                    SET {5}
+                        SET {5}
                     WHEN NOT MATCHED THEN INSERT
-                    ({6}) VALUES ({7})
+                                ({6})
+                        VALUES  ({7})
                     ;
                 DROP TABLE "{0}"."{1}"."{3}" CASCADE;
             """.format(
@@ -261,3 +312,19 @@ class EWAHSnowflakeUploader(EWAHBaseUploader):
                 )
             )
         )
+
+    def get_max_value_of_column(
+        self, column_name, table_name, schema_name, database_name=None
+    ):
+        self.dwh_hook.execute(
+            "USE DATABASE {0}".format(
+                database_name or self.database or self.dwh_hook.conn.database,
+            )
+        )
+        return self.dwh_hook.execute_and_return_result(
+            sql='SELECT MAX("{0}") FROM {1}'.format(
+                column_name,
+                f'"{schema_name}"."{table_name}"',
+            ),
+            return_dict=False,
+        )[0][0]
